===============================
bulv1ne-django-utils
===============================

.. image:: https://img.shields.io/pypi/v/bulv1ne-django-utils.svg
  :target: https://pypi.python.org/pypi/bulv1ne-django-utils

.. image:: https://img.shields.io/travis/bulv1ne/django-utils.svg
  :target: https://travis-ci.org/bulv1ne/django-utils

.. image:: https://coveralls.io/repos/github/bulv1ne/django-utils/badge.svg?branch=master
  :target: https://coveralls.io/github/bulv1ne/django-utils?branch=master


Installing
----------

.. code-block:: bash

  $ pip install bulv1ne-django-utils

Add `'utils'` to `INSTALLED_APPS` in your settings.py:

.. code-block:: python

    INSTALLED_APPS = (
        ...
        'utils',
        ...
    )


Roadmap
-------

:Version 0.1:
  70% test coverage (originally hoped for 100%, some things are harder to test)

:Version 0.2:
  Everything documented
